#
# spec file for package tpm2-tss-engine
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _bashcompletionsdir %{_datadir}/bash-completion/completions
# The directory where crypto engines are located is owned by the libcrypto package.
# Find out where that is.
%define _ENGINE_DIR %(pkg-config --variable=enginesdir libcrypto)
Name:           tpm2-tss-engine
Version:        1.2.0
Release:        3.1
Summary:        OpenSSL Engine for TPM2 devices
License:        BSD-3-Clause
Group:          Productivity/Security
URL:            https://github.com/tpm2-software
Source0:        %{url}/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        %{url}/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz.asc
Source2:        tpm2-tss-engine.keyring
Patch0:         gcc14-fixes.patch
BuildRequires:  autoconf-archive
BuildRequires:  libgcrypt-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  tpm2-0-tss-devel
BuildRequires:  pkgconfig(libcrypto)

%description
The tpm2-tss-engine project implements a cryptographic engine for OpenSSL for
Trusted Platform Module (TPM 2.0) using the tpm2-tss software stack that follows
the Trusted Computing Groups (TCG) TPM Software Stack (TSS 2.0). It uses the
Enhanced System API (ESAPI) interface of the TSS 2.0 for downwards communication.
It supports RSA decryption and signatures as well as ECDSA signatures.

%package bash-completion
Summary:        Bash completion for tpm2-tss-engine
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    packageand(bash-completion:%{name})
BuildArch:      noarch

%description bash-completion
Optional dependency offering bash completion for the tpm2-tss-engine project.

%package devel
Summary:        Devel files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Development files for tpm2-tss-engine, an OpenSSL engine for TPM2 devices.

The tpm2-tss-engine project implements a cryptographic engine for OpenSSL for
Trusted Platform Module (TPM 2.0) using the tpm2-tss software stack that follows
the Trusted Computing Groups (TCG) TPM Software Stack (TSS 2.0). It uses the
Enhanced System API (ESAPI) interface of the TSS 2.0 for downwards communication.
It supports RSA decryption and signatures as well as ECDSA signatures.

%prep
%autosetup -p1

%build

autoreconf -fvi
%configure --with-enginesdir=%{_ENGINE_DIR} --disable-static --disable-defaultflags
make V=1 %{?_smp_mflags}

%install
%make_install bash_completiondir=%{_bashcompletionsdir}
rm %{buildroot}/%{_ENGINE_DIR}/libtpm2tss.la

%files
%doc CHANGELOG.md CONTRIBUTING.md INSTALL.md README.md
%license LICENSE
%{_bindir}/tpm2tss-genkey
%{_mandir}/man1/tpm2tss-genkey.1%{?ext_man}
%{_mandir}/man3/tpm2tss_ecc_genkey.3%{?ext_man}
%{_mandir}/man3/tpm2tss_ecc_getappdata.3%{?ext_man}
%{_mandir}/man3/tpm2tss_ecc_makekey.3%{?ext_man}
%{_mandir}/man3/tpm2tss_ecc_setappdata.3%{?ext_man}
%{_mandir}/man3/tpm2tss_rsa_genkey.3%{?ext_man}
%{_mandir}/man3/tpm2tss_rsa_makekey.3%{?ext_man}
%{_mandir}/man3/tpm2tss_tpm2data_read.3%{?ext_man}
%{_mandir}/man3/tpm2tss_tpm2data_write.3%{?ext_man}
%{_ENGINE_DIR}/libtpm2tss.so
%{_ENGINE_DIR}/tpm2tss.so

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_bashcompletionsdir}/tpm2tss-genkey

%files devel
%{_includedir}/tpm2-tss-engine.h

%changelog
* Mon May  6 2024 Matthias Gerstner <matthias.gerstner@suse.com>
- Add gcc14-fixes.patch: Building with gcc14 fails due to a mismatch in
  OpenSSL function declarations. Provided PR# to upstream here:
  https://github.com/tpm2-software/tpm2-tss-engine/pull/283
- Add tpm2-tss-engine.keyring: needed for validation of the tarball signature.
  This keyring is taken over from tpm2-0-tss which has the same (or very
  similar) maintainers.
* Thu Jun  1 2023 Frederic Crozat <fcrozat@suse.com>
- Fix download url and add gpg signature for tarball.
* Mon Feb  6 2023 Pedro Monreal <pmonreal@suse.com>
- Update to upstream version 1.2.0:
  * Fixed:
  - Updated minimal version of tpm2-tss to 2.4.x
  - Fix encoding of emptyauth
  - Fix some memory leaks
  - Parent handle issues with signed representation by switching
    parent handle to BIGNUM.
  - Fixed RSA_NO_PADDING modes with OpenSSL 1.1.1
  - Fixed autogen (bootstrap) call from release package by
    embedding VERSION file.
  * Added:
  - Use of restricted keys for signing
  - StirRandom
  - Run tests using swtpm
  - The ability to import key blobs from things like the
    tpm2-tools project.
  - Compatibility with openssl >=1.1.x
  - Support for ECDH
  - QNX support.
  - Only set -Werror for non-release builds.
  - Additional checks on TPM responses
  - CODE_OF_CONDUCT
  - SECURITY reporting instructions
* Wed Mar  3 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- pass --disable-defaultflags to avoid breakage of our gcc-PIE profile (->
  resulted in non-position-independent executable) (bsc#1183895).
* Wed Mar  3 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- Update to upstream version 1.1.0:
  * Added:
  - Configure option for ptpm tests
  - Configure script AX_CHECK_ENABLE_DEBUG
  - Option for setting tcti on executable
  - TCTI-env variable used by default
  - Support for parent key passwords
  - openssl.cnf sample file
  * Changed:
  - Fix several build system, autotools and testing related issues
    Now adhere to CFLAGS conventions
  - Include pkg-config dependecy on libtss2-mu in order to work with tpm2-tss 2.3
  - Enables parallel testing of integration tests:
    Make integration tests use TPM simulator; instead of first TPM it finds
    Use of different port numbers for TCP based tests
  - Fix EC param info (using named curve format)
  - Use tpm2-tools 4.X stable branch for integration tests
  - Use libtss2-tctildr.so instead of custom code for tcti setup
  - Fix manpages for -P/--parent option and correct engine name
  - Fix TCTI env variable handling
  - Set parent handle to OWNER
* Thu Apr 23 2020 matthias.gerstner@suse.com
- remove conditional pandoc BuildRequires for openSUSE. Nothing much is gained
  from rebuilding the man pages. This shall help synchronizing SLE and
  openSUSE package builds. (jsc#SLE-12137).
* Fri Jan 10 2020 matthias.gerstner@suse.com
- remove the _service file as requested in declined OBS sr#762653.
  download_files seems to work also without the _service file.
* Fri Jan 10 2020 Matthias Gerstner <matthias.gerstner@suse.com>
- switch the _service approach from using tar_scm to using download_files. We
  need to use the actual release tarball which contains the generated man
  pages. The reason is that on SLE we can't generate the man pages using
  pandoc, since pandoc is not available on SLE.
- for the same reason make the pandoc BuildRequires conditional for openSUSE
  vs. SLE.
* Tue Jan  7 2020 matthias.gerstner@suse.com
- Update to stable upstream version v1.0.1:
  * Release v1.0.1
  * test: use tpm2-tools 3.X
  * Tests: Fix for latest tools
  * Tests: Use long parameters for tpm2-tools
  * test: migrate tpm2_create option from -A to -b
  * build: link against tss2-mu
  * Release v1.0.0
  * Release v1.0.0-rc3
  * Docu: Update Install.md
  * Updates for 1.0.0-rc2
  * TESTS: Add test for client auth
  * Bump required version of tpm2-tss to >=2.2.2
  * Build: Bump required tpm2-tss to 2.2
  * Update for v1.0.0-rc1
  * Dead code removal
- This fixes the build against tpm2-0-tss version >= 2.3 (bsc#1160123)
* Fri Dec 20 2019 matthias.gerstner@suse.com
- move *.so files into the main package, not -devel. libtpm2tss.so is actually
  the engine library itself, not a symlink. It's needed to actually use the
  package. tpm2tss.so is probably a (backwards) compatiblity symlink. Both are
  not intended for linking and therefore not suitable for the -devel package.
* Sun Mar  3 2019 jsikes@suse.de
- Update to version 0+git20190222.cef2c43:
  * build: install existing man pages even if pandoc is not available
  * Updated organizational files in preparation for release
  * Add configure switch for unit and integration tests
  * Silence clang warning on field initializers
  * Fix parallel connections to TPM.
  * Fix segfault on non-null auth'd persistent keys.
  * Update tests to also run on physical TPMs
  * build: install aclocal files
  * build: update for ax_code_coverage.m4 version 2019.01.06
  * ECDSA truncation and s_server test
* Thu Jan 31 2019 Jason Sikes <jsikes@suse.de>
- Now tpm2-tss-engine-bash-completion auto-installs only when bash-completion
  is present.
- Changed author of comment dated "Wed Jan 23 04:39:01 UTC 2019" from
  opensuse-packaging@opensuse.org to me.
* Wed Jan 23 2019 Jan Engelhardt <jengelh@inai.de>
- Build bash-completion as noarch.
* Wed Jan 23 2019 Jason Sikes <jsikes@suse.de>
- Update to version 0+git20190115.6cfaeb7:
  * Initialize/Finalize TCTI based on opts
  * init_tpm_parent: use ESYS_AUXCONTEXT as 1st argument
  * init_tpm_key: use ESYS_AUXCONTEXT as 1st argument
  * tpm2-tss-engine-ecc.c: use ESYS_AUXCONTEXT
  * tpm2-tss-engine-rsa.c: use ESYS_AUXCONTEXT
  * tpm2-tss-engine-rand.c: use ESYS_AUXCONTEXT
  * tpm2tss_tpm2data_readtpm: use ESYS_AUXCONTEXT
  * tpm2-tss-engine-common.(c/h): Add ESYS_AUXCONTEXT
  * Set TCTI option through an environment variable
  * Add new engine control to set the TCTI option
* Mon Dec 24 2018 Jason Sikes <jsikes@suse.de>
- Initial import
  * version 0.0+git20181128.c9061a7
  * FATE 325619
